[SCM] debian-live branch, master, updated. 1.0.0-1-5-gcd2c6ef

Daniel Baumann daniel at debian.org
Mon Aug 25 11:03:50 UTC 2008


The following commit has been merged in the master branch:
commit cd2c6ef93094d33646f1d154c1425897fbbf1004
Author: Daniel Baumann <daniel at debian.org>
Date:   Mon Aug 25 12:51:07 2008 +0200

    Renaming sections to categories in order to use the same names as Debian Policy does (Closes: #483777).

diff --git a/examples/hooks/ipw2100.sh b/examples/hooks/ipw2100.sh
index e23c932..f2e296d 100755
--- a/examples/hooks/ipw2100.sh
+++ b/examples/hooks/ipw2100.sh
@@ -3,7 +3,7 @@
 # This is a hook for live-helper(7) to install ipw2100 drivers
 # To enable it, copy this hook into your config/chroot_local-hooks directory.
 #
-# Note: This hook requires packages from the contrib section. Make sure you enabled
+# Note: This hook requires packages from the contrib category. Make sure you enabled
 # it in your configuration.
 
 # Building kernel module
diff --git a/examples/hooks/ipw2200.sh b/examples/hooks/ipw2200.sh
index 0d91fa8..4b2ed5f 100755
--- a/examples/hooks/ipw2200.sh
+++ b/examples/hooks/ipw2200.sh
@@ -3,7 +3,7 @@
 # This is a hook for live-helper(7) to install ipw2200 drivers
 # To enable it, copy this hook into your config/chroot_local-hooks directory.
 #
-# Note: This hook requires packages from the contrib section. Make sure you enabled
+# Note: This hook requires packages from the contrib category. Make sure you enabled
 # it in your configuration.
 
 # Building kernel mdoule
diff --git a/examples/hooks/ipw3945.sh b/examples/hooks/ipw3945.sh
index 4e1ae1c..5a3eddc 100755
--- a/examples/hooks/ipw3945.sh
+++ b/examples/hooks/ipw3945.sh
@@ -3,7 +3,7 @@
 # This is a hook for live-helper(7) to install ipw3945 drivers
 # To enable it, copy this hook into your config/chroot_local-hooks directory.
 #
-# Note: This hook requires packages from the contrib and non-free section. Make
+# Note: This hook requires packages from the contrib and non-free category. Make
 # sure you enabled it in your configuration.
 
 # Building kernel module
diff --git a/examples/hooks/madwifi.sh b/examples/hooks/madwifi.sh
index bc5d072..ced7695 100755
--- a/examples/hooks/madwifi.sh
+++ b/examples/hooks/madwifi.sh
@@ -3,7 +3,7 @@
 # This is a hook for live-helper(7) to install madwifi drivers
 # To enable it, copy this hook into your config/chroot_localhooks directory.
 #
-# Note: This hook requires packages from the contrib section. Make sure you enabled
+# Note: This hook requires packages from the contrib category. Make sure you enabled
 # it in your configuration.
 
 # Building kernel module
diff --git a/examples/hooks/nvidia-legacy.sh b/examples/hooks/nvidia-legacy.sh
index f4ce544..89f502b 100755
--- a/examples/hooks/nvidia-legacy.sh
+++ b/examples/hooks/nvidia-legacy.sh
@@ -3,7 +3,7 @@
 # This is a hook for live-helper(7) to install nvidia-kernel-legacy drivers
 # To enable it, copy this hook into your config/chroot_localhooks directory.
 #
-# Note: This hook requires packages from the non-free section. Make sure you
+# Note: This hook requires packages from the non-free category. Make sure you
 # enabled it in your configuration.
 
 # Building kernel module
diff --git a/examples/hooks/sun-java5.sh b/examples/hooks/sun-java5.sh
index 82f2d07..049c6c4 100755
--- a/examples/hooks/sun-java5.sh
+++ b/examples/hooks/sun-java5.sh
@@ -3,7 +3,7 @@
 # This is a hook for live-helper(7) to install sun-java.
 # To enable it, copy this hook into your config/chroot_local-hooks directory.
 #
-# Note: This hook requires packages from the non-free section. Make sure you
+# Note: This hook requires packages from the non-free category. Make sure you
 # enabled it in your configuration.
 
 # live-helper sets DEBIAN_FRONTEND to 'noninteractive' to advise debconf to not
diff --git a/examples/hooks/sun-java6.sh b/examples/hooks/sun-java6.sh
index b14c080..01b5ac4 100755
--- a/examples/hooks/sun-java6.sh
+++ b/examples/hooks/sun-java6.sh
@@ -3,7 +3,7 @@
 # This is a hook for live-helper(7) to install sun-java.
 # To enable it, copy this hook into your config/chroot_local-hooks directory.
 #
-# Note: This hook requires packages from the non-free section. Make sure you
+# Note: This hook requires packages from the non-free category. Make sure you
 # enabled it in your configuration.
 
 # live-helper sets DEBIAN_FRONTEND to 'noninteractive' to advise debconf to not
diff --git a/helpers/lh_chroot_sources b/helpers/lh_chroot_sources
index 681d721..24fe495 100755
--- a/helpers/lh_chroot_sources
+++ b/helpers/lh_chroot_sources
@@ -47,22 +47,22 @@ case "${1}" in
 		Create_lockfile .lock
 
 		# Configure custom sources.list
-		echo "deb ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_SECTIONS}" > chroot/etc/apt/sources.list
+		echo "deb ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" > chroot/etc/apt/sources.list
 
 		if [ "${LH_SOURCE}" = "enabled" ]
 		then
-			echo "deb-src ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_SECTIONS}" >> chroot/etc/apt/sources.list
+			echo "deb-src ${LH_MIRROR_CHROOT} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
 		fi
 
 		if [ "${LH_SECURITY}" = "enabled" ]
 		then
 			if [ "${LH_DISTRIBUTION}" != "sid" ] && [ "${LH_DISTRIBUTION}" != "unstable" ]
 			then
-				echo "deb ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_SECTIONS}" >> chroot/etc/apt/sources.list
+				echo "deb ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
 
 				if [ "${LH_SOURCE}" = "enabled" ]
 				then
-					echo "deb-src ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_SECTIONS}" >> chroot/etc/apt/sources.list
+					echo "deb-src ${LH_MIRROR_CHROOT_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
 				fi
 			fi
 		fi
@@ -348,22 +348,22 @@ case "${1}" in
 			rm -rf chroot/var/lib/apt/lists
 			mkdir -p chroot/var/lib/apt/lists/partial
 
-			echo "deb ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_SECTIONS}" > chroot/etc/apt/sources.list
+			echo "deb ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" > chroot/etc/apt/sources.list
 
 			if [ "${LH_SOURCE}" = "enabled" ]
 			then
-				echo "deb-src ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_SECTIONS}" >> chroot/etc/apt/sources.list
+				echo "deb-src ${LH_MIRROR_BINARY} ${LH_DISTRIBUTION} ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
 			fi
 
 			if [ "${LH_SECURITY}" = "enabled" ]
 			then
 				if [ "${LH_DISTRIBUTION}" != "sid" ] && [ "${LH_DISTRIBUTION}" != "unstable" ]
 				then
-					echo "deb ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_SECTIONS}" >> chroot/etc/apt/sources.list
+					echo "deb ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
 
 					if [ "${LH_SOURCE}" = "enabled" ]
 					then
-						echo "deb-src ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_SECTIONS}" >> chroot/etc/apt/sources.list
+						echo "deb-src ${LH_MIRROR_BINARY_SECURITY} ${LH_DISTRIBUTION}/updates ${LH_CATEGORIES}" >> chroot/etc/apt/sources.list
 					fi
 				fi
 			fi
diff --git a/helpers/lh_config b/helpers/lh_config
index d8a44e0..67cbd02 100755
--- a/helpers/lh_config
+++ b/helpers/lh_config
@@ -99,7 +99,7 @@ USAGE="${PROGRAM} [--apt apt|aptitude]\n\
 \t    [--quiet]\n\
 \t    [--root-command sudo]\n\
 \t    [--use-fakeroot enabled|disabled]\n\
-\t    [--sections SECTION|\"SECTIONS\"]\n\
+\t    [--categories CATEGORY|\"CATEGORIES\"]\n\
 \t    [--security enabled|disabled]\n\
 \t    [--source enabled|disabled]\n\
 \t    [-s|--source-images iso|net|tar|usb-hdd]\n\
@@ -119,7 +119,7 @@ USAGE="${PROGRAM} [--apt apt|aptitude]\n\
 
 Local_arguments ()
 {
-	ARGUMENTS="$(getopt --longoptions apt:,apt-ftp-proxy:,apt-http-proxy:,apt-pdiffs:,apt-options:,aptitute-options:,apt-pipeline:,apt-recommends:,apt-secure:,bootstrap:,cache:,cache-indices:,cache-packages:,cache-stages:,debconf-frontend:,debconf-nowarnings:,debconf-priority:,genisoimage:,initramfs:,fdisk:,losetup:,mode:,root-command:,use-fakeroot:,tasksel:,includes:,templates:,architecture:,bootstrap-config:,bootstrap-flavour:,bootstrap-keyring:,distribution:,mirror-bootstrap:,mirror-chroot:,mirror-chroot-security:,mirror-binary:,mirror-binary-security:,sections:,chroot-filesystem:,union-filesystem:,exposed-root:,hooks:,interactive:,keyring-packages:,language:,linux-flavours:,linux-packages:,packages:,packages-lists:,tasks:,security:,symlinks:,sysvinit:,binary-filesystem:,binary-images:,binary-indices:,bootappend-install:,bootappend-live:,bootloader:,checksums:,chroot-build:,debian-installer:,,debian-installer-distribution:,debian-installer-preseedfile:,encryption:,grub-splash:,hostname:,iso-application:,iso-preparer:,iso-publisher:,iso-volume:,jffs2-eraseblock:,memtest:,net-root-filesystem:,net-root-mountoptions:,net-root-path:,net-root-server:,net-cow-filesystem:,net-cow-mountoptions:,net-cow-path:,net-cow-server:,net-tarball:,syslinux-splash:,syslinux-timeout:,syslinux-menu:,username,:win32-loader:,source:,source-images:,breakpoints,conffile:,debug,force,help,ignore-system-defaults,quiet,usage,verbose,version--name=${PROGRAM} --options a:f:d:m:l:k:p:b:e:s:c:huv --shell sh -- "${@}")"
+	ARGUMENTS="$(getopt --longoptions apt:,apt-ftp-proxy:,apt-http-proxy:,apt-pdiffs:,apt-options:,aptitute-options:,apt-pipeline:,apt-recommends:,apt-secure:,bootstrap:,cache:,cache-indices:,cache-packages:,cache-stages:,debconf-frontend:,debconf-nowarnings:,debconf-priority:,genisoimage:,initramfs:,fdisk:,losetup:,mode:,root-command:,use-fakeroot:,tasksel:,includes:,templates:,architecture:,bootstrap-config:,bootstrap-flavour:,bootstrap-keyring:,distribution:,mirror-bootstrap:,mirror-chroot:,mirror-chroot-security:,mirror-binary:,mirror-binary-security:,categories:,chroot-filesystem:,union-filesystem:,exposed-root:,hooks:,interactive:,keyring-packages:,language:,linux-flavours:,linux-packages:,packages:,packages-lists:,tasks:,security:,symlinks:,sysvinit:,binary-filesystem:,binary-images:,binary-indices:,bootappend-install:,bootappend-live:,bootloader:,checksums:,chroot-build:,debian-installer:,,debian-installer-distribution:,debian-installer-preseedfile:,encryption:,grub-splash:,hostname:,iso-application:,iso-preparer:,iso-publisher:,iso-volume:,jffs2-eraseblock:,memtest:,net-root-filesystem:,net-root-mountoptions:,net-root-path:,net-root-server:,net-cow-filesystem:,net-cow-mountoptions:,net-cow-path:,net-cow-server:,net-tarball:,syslinux-splash:,syslinux-timeout:,syslinux-menu:,username,:win32-loader:,source:,source-images:,breakpoints,conffile:,debug,force,help,ignore-system-defaults,quiet,usage,verbose,version--name=${PROGRAM} --options a:f:d:m:l:k:p:b:e:s:c:huv --shell sh -- "${@}")"
 
 	if [ "${?}" != "0" ]
 	then
@@ -343,8 +343,8 @@ Local_arguments ()
 				shift 2
 				;;
 
-			--sections)
-				LH_SECTIONS="${2}"
+			--categories)
+				LH_CATEGORIES="${2}"
 				shift 2
 				;;
 
@@ -876,9 +876,9 @@ LH_MIRROR_BINARY="${LH_MIRROR_BINARY}"
 # (Default: ${LH_MIRROR_BINARY_SECURITY})
 LH_MIRROR_BINARY_SECURITY="${LH_MIRROR_BINARY_SECURITY}"
 
-# \$LH_SECTIONS: select section(s) to use
-# (Default: ${LH_SECTIONS})
-LH_SECTIONS="${LH_SECTIONS}"
+# \$LH_CATEGORIES: select categories to use
+# (Default: ${LH_CATEGORIES})
+LH_CATEGORIES="${LH_CATEGORIES}"
 EOF
 
 # Creating lh_chroot_* configuration
diff --git a/lists/rescue b/lists/rescue
index 14d985f..e02e041 100644
--- a/lists/rescue
+++ b/lists/rescue
@@ -33,7 +33,7 @@ lynx links2 w3m
 # Compression
 bzip2 unace unrar-free unzip zip
 
-#if SECTIONS non-free
+#if CATEGORIES non-free
 rar unrar
 #endif
 
diff --git a/manpages/lh_config.en.1 b/manpages/lh_config.en.1
index 0f6380a..2e44bf6 100644
--- a/manpages/lh_config.en.1
+++ b/manpages/lh_config.en.1
@@ -144,7 +144,7 @@ lh_config \- create configuration for live\-helper
 .br
 	[\fB\-\-use-fakeroot\fR enabled|disabled]
 .br
-	[\fB\-\-sections\fR \fISECTION\fR|\fI"SECTIONS"\fR]
+	[\fB\-\-categories\fR \fICATEGORY\fR|\fI"CATEGORIES"\fR]
 .br
 	[\fB\-\-security\fR enabled|disabled]
 .br
@@ -259,7 +259,7 @@ Example:
 .IP "\fB\-\-packages\fR \fIPACKAGE\fR|\fI""PACKAGES""\fR" 4
 .IP "\fB\-\-root\-command\fR sudo" 4
 .IP "\fB\-\-use\-fakeroot\fR enabled|disabled" 4
-.IP "\fB\-\-sections\fR \fISECTION\fR|\fI""SECTIONS""\fR" 4
+.IP "\fB\-\-categories\fR \fICATEGORY\fR|\fI""CATEGORIES""\fR" 4
 .IP "\fB\-\-security\fR enabled|disabled" 4
 .IP "\fB\-\-source\fR enabled|disabled" 4
 .IP "\-s|\fB\-\-source\-images\fR iso|net|tar|usb\-hdd" 4
diff --git a/manpages/po4a/de/lh_config.en.1.po b/manpages/po4a/de/lh_config.en.1.po
index cecf330..7fe48b1 100644
--- a/manpages/po4a/de/lh_config.en.1.po
+++ b/manpages/po4a/de/lh_config.en.1.po
@@ -504,7 +504,7 @@ msgstr ""
 
 # type: Plain text
 #: lh_config.en.1:148
-msgid "  [B<--sections> I<SECTION>|I<\"SECTIONS\">]"
+msgid "  [B<--categories> I<CATEGORY>|I<\"CATEGORIES\">]"
 msgstr ""
 
 # type: Plain text
@@ -1013,7 +1013,7 @@ msgstr ""
 # type: IP
 #: lh_config.en.1:262
 #, no-wrap
-msgid "B<--sections> I<SECTION>|I<\"SECTIONS\">"
+msgid "B<--categories> I<CATEGORY>|I<\"CATEGORIES\">"
 msgstr ""
 
 # type: IP
diff --git a/manpages/po4a/fr/lh_config.en.1.po b/manpages/po4a/fr/lh_config.en.1.po
index e906caa..f6e822c 100644
--- a/manpages/po4a/fr/lh_config.en.1.po
+++ b/manpages/po4a/fr/lh_config.en.1.po
@@ -513,7 +513,7 @@ msgstr ""
 
 # type: Plain text
 #: lh_config.en.1:148
-msgid "  [B<--sections> I<SECTION>|I<\"SECTIONS\">]"
+msgid "  [B<--categories> I<CATEGORY>|I<\"CATEGORIES\">]"
 msgstr ""
 
 # type: Plain text
@@ -1022,7 +1022,7 @@ msgstr ""
 # type: IP
 #: lh_config.en.1:262
 #, no-wrap
-msgid "B<--sections> I<SECTION>|I<\"SECTIONS\">"
+msgid "B<--categories> I<CATEGORY>|I<\"CATEGORIES\">"
 msgstr ""
 
 # type: IP
diff --git a/manpages/po4a/pot/lh_config.en.1.pot b/manpages/po4a/pot/lh_config.en.1.pot
index 9f6b843..e65ebf9 100644
--- a/manpages/po4a/pot/lh_config.en.1.pot
+++ b/manpages/po4a/pot/lh_config.en.1.pot
@@ -504,7 +504,7 @@ msgstr ""
 
 # type: Plain text
 #: lh_config.en.1:148
-msgid "  [B<--sections> I<SECTION>|I<\"SECTIONS\">]"
+msgid "  [B<--categories> I<CATEGORY>|I<\"CATEGORIES\">]"
 msgstr ""
 
 # type: Plain text
@@ -1013,7 +1013,7 @@ msgstr ""
 # type: IP
 #: lh_config.en.1:262
 #, no-wrap
-msgid "B<--sections> I<SECTION>|I<\"SECTIONS\">"
+msgid "B<--categories> I<CATEGORY>|I<\"CATEGORIES\">"
 msgstr ""
 
 # type: IP

diff --git a/functions/defaults.sh b/functions/defaults.sh
index 9c4d2d3..2f817a2 100755
--- a/functions/defaults.sh
+++ b/functions/defaults.sh
@@ -319,10 +319,10 @@ Set_defaults ()
 		LH_MIRROR_BINARY_SECURITY="http://security.debian.org/"
 	fi
 
-	# Setting sections value
-	if [ -z "${LH_SECTIONS}" ]
+	# Setting categories value
+	if [ -z "${LH_CATEGORIES}" ]
 	then
-		LH_SECTIONS="main"
+		LH_CATEGORIES="main"
 	fi
 
 	## config/chroot
-- 
debian-live



More information about the debian-live-changes mailing list